import matplotlib.pyplot as plt
import pandas as pd
import matplotlib.dates as mdates
from pandas.plotting import register_matplotlib_converters
register_matplotlib_converters()
import matplotlib.ticker as tick

#Extraction des données depuis le fichier .csv :
soleil=pd.read_csv('SoleilLune2022.csv',
sep=';', 
usecols=[1, 2, 4, 6], 
names=['date', 'lever', 'midi', 'coucher'], 
parse_dates=['date'], 
skiprows=1, 
nrows=365, 
)
#Extraction des listes de données pour les graphes :
soleil=soleil.set_index('date')
dates=soleil.index
lever=soleil['lever']
coucher=soleil['coucher']
midi=soleil['midi']
EDT=midi-12#calcul de l'équation du temps

plt.rcParams["font.family"] = "Ubuntu"
plt.rcParams["font.size"] = 9

def HHmm(heure, lever):#écrit en base 60
    H=int(heure)
    min=round((heure-H)*60)
    if min<10:
        min="0"+str(min)
    return str(H)+'h'+str(min)[:-2]

def pointMinimum(liste, datemin, datemax):
    periode=liste.loc[datemin:datemax]
    Tmin=periode.idxmin(periode)
    Hmin=periode.values.min()
    ax=plt.gca()
    ax.scatter(Tmin, Hmin, c='white', facecolor='w',
    edgecolor='k', zorder=2)

def pointMaximum(liste, datemin, datemax):
    periode=liste.loc[datemin:datemax]
    Tmax=periode.idxmax(periode)
    Hmax=periode.values.max()
    ax=plt.gca()
    ax.scatter(Tmax, Hmax, c='white', facecolor='w',
    edgecolor='k', zorder=2)

#Paramètres du graphique :
fig=plt.figure(figsize=(7, 9), tight_layout=True)

#Graphe 6---------------------------------------------------
ax6=plt.subplot(211)
ax6.set_title("Coucher du Soleil au solstice d'hiver")
ax6.plot(dates, coucher, label='temps moyen', c='C0')
ax6.plot(dates, coucher-EDT, label='temps vrai', c='C2', ls='--')
ax6.grid()
ax6.yaxis.set_major_formatter(tick.FuncFormatter(HHmm))
locator2 = mdates.AutoDateLocator(minticks=15, maxticks=15, interval_multiples=True)
ax6.xaxis.set_major_locator(locator2)
formatter = mdates.ConciseDateFormatter(locator2)
ax6.xaxis.set_major_formatter(formatter)
ax6.set_xlim('2022-12-05', '2022-12-31')
ax6.set_ylim(15.9, 16.2)
ax6.legend()

pointMinimum(coucher, '2022-12-10', '2022-12-31')
pointMinimum(coucher-EDT, '2022-12-10', '2022-12-31')

#Graphe 7---------------------------------------------------
ax7=plt.subplot(212)
ax7.set_title("Lever du Soleil au solstice d'hiver")
ax7.plot(dates, lever, label='temps moyen', c='C1')
ax7.plot(dates, lever-EDT, label='temps vrai', c='C3', ls='--')
ax7.grid()
ax7.yaxis.set_major_formatter(tick.FuncFormatter(HHmm))
locator2 = mdates.AutoDateLocator(minticks=15, maxticks=15, interval_multiples=True)
ax7.xaxis.set_major_locator(locator2)
ax7.xaxis.set_major_formatter(formatter)
ax7.set_xlim('2022-12-05', '2022-12-31')
ax7.set_ylim(7.85, 8.01)
ax7.legend()

pointMaximum(lever, '2022-12-10', '2022-12-31')
pointMaximum(lever-EDT, '2022-12-10', '2022-12-31')

fig.savefig("LeverCoucherSoleil_3.png", dpi=200)
plt.show()
